@@ -1,9 +1,9 @@
 ##
 ## fft_filter: fftw interface
 ##
-## $Header: /home/repository/rimage/R/fft_filter.R,v 1.4.2.4 2003/04/07 07:32:29 tomo Exp $
+## $Header: /database/repository/rimage/R/fft_filter.R,v 1.4.2.5 2004/03/17 06:35:05 tomo Exp $
 ##
-## Copyright (c) 2003 Nikon Digital Technologies Co., Ltd.
+## Copyright (c) 2003 Nikon Systems Inc.
 ## For complete license terms see file LICENSE
 
 fftw <- function(img, dir = -1, debug=FALSE) {
@@ -15,7 +15,8 @@ fftw <- function(img, dir = -1, debug=FALSE) {
             as.integer(h),
             as.integer(dir),
             as.integer(debug),
-            spec = complex(w*h)
+            spec = complex(w*h),
+            PACKAGE="rimage"
             )$spec, nrow=dim(img)[1], ncol=dim(img)[2])
 }
 
